@@ -272,7 +272,7 @@ class Walker(ListWalker):
         if self.flags & self.display_size and node.field.size or self.flags & self.display_type:
             tmp_text = []
             if self.flags & self.display_type:
-                tmp_text.append(node.field.__class__.__name__)
+                tmp_text.append(node.field.getFieldType())
             if self.flags & self.display_size:
                 if node.field.size % 8:
                     tmp_text.append( humanBitSize(node.field.size) )
@@ -622,7 +622,7 @@ def exploreFieldSet(field_set, args, options={}):
                         e = top.keypress(size, e)
                         if e is None:
                             pass
-                        elif e == 'f1':
+                        elif e in ('f1', '?'):
                             try:
                                 body.select(body.tabs.index(help))
                             except ValueError:
